==> recursive-readdir-1.2.31.tgz: recursive-readdir v1.2/README.md <==
# Installation
> `npm install --save @types/recursive-readdir`

# Summary
This package contains type definitions for recursive-readdir (https://github.com/jergason/recursive-readdir/).

# Details
Files were exported from https://github.com/DefinitelyTyped/DefinitelyTyped/tree/master/types/recursive-readdir/v1.
## [index.d.ts](https://github.com/DefinitelyTyped/DefinitelyTyped/tree/master/types/recursive-readdir/v1/index.d.ts)
````ts
// Type definitions for recursive-readdir v1.2.1
// Project: https://github.com/jergason/recursive-readdir/
// Definitions by: DefinitelyTyped <https://github.com/DefinitelyTyped>
// Definitions: https://github.com/DefinitelyTyped/DefinitelyTyped

/// <reference types="node" />


import * as fs from "fs";
declare namespace RecursiveReaddir {
    interface readdir {
        (path: string, callback: (error: Error, files: string[]) => any): void;
        // ignorePattern supports glob syntax via https://github.com/isaacs/minimatch
        (path: string, ignorePattern: (string | ((file: string, stats: fs.Stats) => void))[], callback: (error: Error, files: string[]) => any): void;
        (path: string, ignoreFunction: (file: string, stats: fs.Stats) => void, callback: (error: Error, files: string[]) => any): void;
    }
}

declare var r: RecursiveReaddir.readdir;
export = r;

````

### Additional Details
 * Last updated: Thu, 14 Apr 2022 17:01:30 GMT
 * Dependencies: [@types/node](https://npmjs.com/package/@types/node)
 * Global values: none

# Credits
These definitions were written by [DefinitelyTyped](https://github.com/DefinitelyTyped).

==> recursive-readdir-1.2.32.tgz: recursive-readdir v1.2/README.md <==
# Installation
> `npm install --save @types/recursive-readdir`

# Summary
This package contains type definitions for recursive-readdir (https://github.com/jergason/recursive-readdir/).

# Details
Files were exported from https://github.com/DefinitelyTyped/DefinitelyTyped/tree/master/types/recursive-readdir/v1.
## [index.d.ts](https://github.com/DefinitelyTyped/DefinitelyTyped/tree/master/types/recursive-readdir/v1/index.d.ts)
````ts
// Type definitions for recursive-readdir v1.2.1
// Project: https://github.com/jergason/recursive-readdir/
// Definitions by: DefinitelyTyped <https://github.com/DefinitelyTyped>
// Definitions: https://github.com/DefinitelyTyped/DefinitelyTyped

/// <reference types="node" />

import * as fs from "fs";
declare namespace RecursiveReaddir {
    interface readdir {
        (path: string, callback: (error: Error, files: string[]) => any): void;
        // ignorePattern supports glob syntax via https://github.com/isaacs/minimatch
        (
            path: string,
            ignorePattern: (string | ((file: string, stats: fs.Stats) => void))[],
            callback: (error: Error, files: string[]) => any,
        ): void;
        (
            path: string,
            ignoreFunction: (file: string, stats: fs.Stats) => void,
            callback: (error: Error, files: string[]) => any,
        ): void;
    }
}

declare var r: RecursiveReaddir.readdir;
export = r;

````

### Additional Details
 * Last updated: Wed, 27 Sep 2023 07:12:04 GMT
 * Dependencies: [@types/node](https://npmjs.com/package/@types/node)
 * Global values: none

# Credits
These definitions were written by [DefinitelyTyped](https://github.com/DefinitelyTyped).
